# What it does
Upon running the program, a virtual avatar will appear.

The avatar's mouse will move given your mouse movements.

Upon pressing the left, middle, or right button, the avatar will perform a "clicking" animation.

Upon pressing an alphanumerical character or 'space', the avatar will perform a "key press" animation.

Different mouse and keyboard buttons will simulate animations in slightly different locations.

There may be a green border around the character, but software like OBS will ignore it.

# How to use
Go to the releases page and download Wolfy.Zip.

https://github.com/Sparks29032/Character_Plugin/releases

Click on the "Wolfy" executable to run.

**NOTE:** Having caps lock or holding shift may mess with reading in the button presses.

### Use with OBS
Use a "Window Capture" on the Wolfy.exe program.

To get rid of the green color background, use a Chroma Key filter with the settings: ~333 Similarity, 1 Smoothness, 1 Key Color Spill Reduction.

### Using your own avatar
To use your own avatars, you simply have to change the pictures in the "Images" folder.

However, refrain from #00ff00 as that color will be displayed as clear.

Ensure your images are around the same height as the current model.
